@@ -2,7 +2,8 @@ from dataclasses import dataclass
 from typing import Optional
 
 from src.entities.file import File
-from src.enums.block_type import BlockType
+from src.types.block_type import BlockType
+from src.types.lines import Lines
 from src.utils import to_snake_case
 
 
@@ -12,13 +13,13 @@ class GenerateImportStatementService:
     init_file: File
     exclude_file: Optional[File] = None
 
-    def execute(self) -> list[str]:
+    def execute(self) -> Lines:
         # Generate import statements for moved and non-moved blocks
         new_dir_path = str(self.init_file.path.parent).replace("/", ".")
         import_statement = []
         # Add import statements from the original file
         for non_moved_block in filter(lambda block: block.type == BlockType.IMPORT, self.init_file.blocks):
-            import_statement += non_moved_block.codes
+            import_statement += non_moved_block.lines
         # Add import statements for moved blocks
         for moved_file in filter(lambda file: file != self.exclude_file, self.moved_files):
             for block in moved_file.blocks:
