@@ -4,6 +4,7 @@ import pytest
 
 from src.entities.block import Block
 from src.services.load_file_service import LoadFileService
+from src.types.block_type import BlockType
 
 
 def test_load_file_service():
@@ -11,9 +12,9 @@ def test_load_file_service():
     result = service.execute()
     assert result.path == Path("tests/samples/models.py")
     assert result.blocks[0] == Block(
-        type="import",
+        type=BlockType.IMPORT,
         name="other",
-        codes=[
+        lines=[
             "# This is a sample file for testing.\n",
             '"""\n',
             "This is a sample file for testing.\n",
@@ -22,31 +23,31 @@ def test_load_file_service():
             "import sys\n",
         ],
     )
-    assert result.blocks[1] == Block(type="import", name="other", codes=["from dataclasses import dataclass\n"])
+    assert result.blocks[1] == Block(type=BlockType.IMPORT, name="other", lines=["from dataclasses import dataclass\n"])
     assert result.blocks[2] == Block(
-        type="import", name="other", codes=["from typing import (\n", "    Callable\n", ")\n"]
+        type=BlockType.IMPORT, name="other", lines=["from typing import (\n", "    Callable\n", ")\n"]
     )
-    assert result.blocks[3] == Block(type="import", name="other", codes=["from pathlib import Path\n"])
-    assert result.blocks[4] == Block(type="value", name="StrAlias", codes=["\n", "StrAlias = str\n"])
+    assert result.blocks[3] == Block(type=BlockType.IMPORT, name="other", lines=["from pathlib import Path\n"])
+    assert result.blocks[4] == Block(type=BlockType.VALUE, name="StrAlias", lines=["\n", "StrAlias = str\n"])
     assert result.blocks[5] == Block(
-        type="value",
+        type=BlockType.VALUE,
         name="FunctionAlias",
-        codes=["# This is very important value\n", "FunctionAlias = Callable[[], None]\n"],
+        lines=["# This is very important value\n", "FunctionAlias = Callable[[], None]\n"],
     )
     assert result.blocks[6] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithMetaKlass",
-        codes=["\n", "\n", "class KlassWithMetaKlass:\n", "    class Meta:\n", "        abstract = True\n"],
+        lines=["\n", "\n", "class KlassWithMetaKlass:\n", "    class Meta:\n", "        abstract = True\n"],
     )
     assert result.blocks[7] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="_KlassNameStartWithUnderScore",
-        codes=["\n", "\n", "class _KlassNameStartWithUnderScore:\n", "    pass\n"],
+        lines=["\n", "\n", "class _KlassNameStartWithUnderScore:\n", "    pass\n"],
     )
     assert result.blocks[8] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithComment1",
-        codes=[
+        lines=[
             "\n",
             "\n",
             '"""\n',
@@ -59,9 +60,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[9] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithComment2",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "'''\n",
@@ -75,9 +76,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[10] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithComment3",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "# This is very important comment for KlassWithComment3\n",
@@ -87,14 +88,14 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[11] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithDecorator",
-        codes=["\n", "\n", "@dataclass(frozen=True)\n", "class KlassWithDecorator:\n", "    pass\n"],
+        lines=["\n", "\n", "@dataclass(frozen=True)\n", "class KlassWithDecorator:\n", "    pass\n"],
     )
     assert result.blocks[12] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithCommentAndDecorator",
-        codes=[
+        lines=[
             "\n",
             "\n",
             '"""\n',
@@ -111,13 +112,13 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[13] == Block(
-        type="value", name="class_value1", codes=["\n", "\n", 'class_value1 = "default1"\n']
+        type=BlockType.VALUE, name="class_value1", lines=["\n", "\n", 'class_value1 = "default1"\n']
     )
-    assert result.blocks[14] == Block(type="value", name="class_value2", codes=['class_value2 = "default2"\n'])
+    assert result.blocks[14] == Block(type=BlockType.VALUE, name="class_value2", lines=['class_value2 = "default2"\n'])
     assert result.blocks[15] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithMember",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "class KlassWithMember:\n",
@@ -126,9 +127,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[16] == Block(
-        type="class",
+        type=BlockType.CLASS,
         name="KlassWithFunction",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "class KlassWithFunction(KlassWithComment1):\n",
@@ -137,9 +138,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[17] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="_function_start_with_underscore",
-        codes=[
+        lines=[
             "\n",
             "\n",
             'if __name__ == "__main__":\n',
@@ -152,9 +153,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[18] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_comment1",
-        codes=[
+        lines=[
             "\n",
             "\n",
             '"""\n',
@@ -167,9 +168,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[19] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_comment2",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "'''\n",
@@ -183,9 +184,9 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[20] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_comment3",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "# This is very important comment for function_with_comment3\n",
@@ -195,15 +196,15 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[21] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_decorator",
-        codes=["\n", "\n", "@staticmethod\n", "def function_with_decorator():\n", "    pass\n"],
+        lines=["\n", "\n", "@staticmethod\n", "def function_with_decorator():\n", "    pass\n"],
     )
-    assert result.blocks[22] == Block(type="value", name="def_value", codes=["\n", "\n", "def_value = 1\n"])
+    assert result.blocks[22] == Block(type=BlockType.VALUE, name="def_value", lines=["\n", "\n", "def_value = 1\n"])
     assert result.blocks[23] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_comment_and_decorator",
-        codes=[
+        lines=[
             "\n",
             "\n",
             "# this comment for function_with_comment_and_decorator\n",
@@ -213,11 +214,11 @@ def test_load_file_service():
         ],
     )
     assert result.blocks[24] == Block(
-        type="function",
+        type=BlockType.FUNCTION,
         name="function_with_async",
-        codes=["\n", "\n", "async def function_with_async():\n", "    pass\n"],
+        lines=["\n", "\n", "async def function_with_async():\n", "    pass\n"],
     )
-    assert result.blocks[25] == Block(type="value", name="last_value", codes=["\n", "\n", "last_value = 100\n"])
+    assert result.blocks[25] == Block(type=BlockType.VALUE, name="last_value", lines=["\n", "\n", "last_value = 100\n"])
 
 
 def test_load_file_service_non_existent_file():
